# Unlocked Literal Bible - English

*an unrestricted Bible intended for translation into any language*

This work is based on *The American Standard Version*, which is in the public domain.
This repository contains the USFM source files for the English Unlocked Literal Bible.

## Contributors

If you are a contributor to this project please add your name to the `contributor`
field in the [manifest.yaml](https://git.door43.org/Door43/en_ulb/src/master/manifest.yaml)
file.

## Viewing

To view the rendered USFM files, go to https://live.door43.org/u/Door43/en_ulb/

To view the translationNotes, go to https://git.door43.org/Door43/en_tn
 
## Editing

### Introduction to the ULB

The ULB (Unlocked Literal Bible) is a relatively "literal" version that is intended to be used as a text for presenting the ideas signaled by the biblical Hebrew, Aramaic, and Greek documents, for the purpose of bringing these ideas into other languages. It is intended for English-speaking mother-tongue translators (MTTs) worldwide as a resource for them to turn God's Word into their own languages.

The ULB stays closer to language **forms** in the source documents (SD) than does the UDB (Unlocked Dynamic Bible) text. This means that:

  * the ULB reflects better than the UDB the SD's use of grammatical structures belonging to the biblical languages.
  * the ULB reflects better than the UDB the SD's use of parts of speech that belong to the biblical languages. The ULB, for example, is likely to use nouns where the SD uses nouns, adjectives where the SD uses adjectives, and so forth. This is often true right down to the level of the use of many Hebrew and Greek grammatical particles. Thus, for example, the ULB is likely to read, *the kingdom of light*  instead of giving some more dynamic rendering such as, *the kingdom where all is light*, etc.
  * the ULB is likely to reproduce the form of the SD logical connections more closely than does the UDB. Thus, for example, the ULB will read, *the righteousness of faith*, even though the logical relationship between *righteousness* and *faith* is not further specified (is it the righteousness that comes by faith? is it the righteousness that vindicates faith?) All that *the righteousness of faith* explicitly signals is that there is some close association in the text between *righteousness* and *faith*, and that we can probably rule out **a number of ** conceivable logical relationships between the two concepts, but not **all ** possible relationships, as the foregoing example illustrates. In contrast, the UDB may choose the one logical relationship that seems most likely.
  * the ULB is likely to reproduce the linear succession of ideas found in the SD, even when English prefers a different arrangement of the same ideas.
  * the ULB presents far less information that is only **implied **  in the SD than does the UDB. For example, in Matt. 26:5 *For they were saying, "Not during the feast, so that a riot does not arise among the people."*  the implied information is, "Let us not arrest Jesus [during the feast]." The ULB will not overtly represent this implied information.
  * the ULB reflects as much as reasonably possible the SD's written style: it reads, for example, "Paul...to Timothy..." instead of English's preferred, "Dear Timothy, [new paragraph] this is Paul."
  * However, the ULB departs from closely representing the SD's structures when it must do so for the sake of clarity in English.
  * the ULB is not meant to be a refined, polished English version. It is meant to present the meaning and structure of the original in so far as that can be done clearly and simply, so that it can, in turn, be translated into other languages.

There remains one over-arching principle for the ULB: even if it sometimes conveys **less **  than the complete sense of the SD (because it seeks to represent SD structures which can be ambiguous in English), **the ULB must never promote to the MTT the wrong sense**.

### The Text from which the ULB Is Being Adapted

The ULB is an adaptation of the 1901 American Standard Version (ASV). The ASV is a very literal translation, and it has many outdated words. Most of these words are being replaced in the ULB with present-day vocabulary using automatic scripting on the server. The editing team needs to correct any outdated words that remain (as well as any mistakes made by the automated "correction" process), so that the text will be understandable to a modern audience. The editors will also change phrases and the order of phrases of the ASV that are unnatural in modern English, making it easier to understand while still keeping it close to the meaning and structure of the Greek text.

### Style of the ULB

The ULB will remain fairly literal in style. As much as possible, complex theological terms and other translation issues will be explained in the translation notes that are provided along with the ULB texts. In addition, the ULB will be accompanied by the UDB, which will show alternate ways of expressing the meaning in a more natural way. The translation notes will also offer alternative translation suggestions. Links to explanations for important terms that are repeated throughout the Bible will be provided along with the ULB text. Therefore, it is acceptable for the ULB to retain some of the ASV's specialized terminology, as long as the result makes good sense in modern English. Figures of speech will be retained in the ULB and replaced by plain language in the UDB.

The edit team members will:

  * Remove archaic language and replace with modern, clear English.
  * Replace most colons and semicolons with commas and periods according to current English style.
  * Make sure the text accurately expresses the meaning of the Greek text.
  * Check that the English level is easy to understand.
  * Retain the basically literal nature of the text–it should complement the "dynamic" UDB rather than be similar to it.

Specific editing guidelines:

  * Only use quotation marks at the beginning and ending of direct speech. Do not put quotation marks at the beginning of each verse, even though the speech may span several verses.
  * Do not use contractions.
  * Punctuation marks go inside the quote marks.
  * Capitalization issues: in general, we are following the practice of the 2011 NIV.
  * All pronouns are lower case (except when beginning sentences and except for the first singular "I").
  * Capitalize titles (Son of Man, King David, the Messiah).
  * Try to find other ways to translate the Greek participle. Many languages do not have participles.

### Translation Glossary

A list of decisions as to how to translate some senses of the SD's words and phrases into another language is called a Translation Glossary (TG). Such a device is especially useful when more than one person works on the same project, because it helps keep everyone using the same English terms.

However, a TG cannot be foolproof, because the SD will often use some words to signal more than one sense, depending on context. A TG is therefore a glossary of **word senses**, not a glossary of **words**. Check back often to this page, because this TG is likely to develop for the entire life of the Unfolding Word project.

Note that occasionally, the TG's specified translation will not be suitable. As always, the text editors must remain in control of the decision-making process. The TG is to guide you as much as is possible. If you must depart from the TG guidelines, do so and insert a note to that effect.

#### Translation Glossary for the Old Testament ULB

Preferred English renderings appear in bold type.

  * *wayehi* "**It came about,**" "**It happened that...**"
  * *hinneh* "**Behold**" (when used in normal narrative passages or in narrative embedded in direct speech, such as when Joseph tells his brothers what happened in his dreams). In conversational passages, translate *hinneh *  as, "**look**," "**see**," "**see here**," or something else suitable for signaling that what immediately follows in the text is prominent. Some conversational contexts may make it almost impossible to give any translation at all of *hinneh*. – However, in direct reported speech of God or his angel, you may use "**behold**," especially if it lends more dignity in English to the divine words than "look" or "see," etc., would do.
  * *brethren*  should be updated to **brothers**. When both genders are indicated by the context, a note from the Notes Team should be expected to appear to that effect. Do not replace the ULB text with "brothers and sisters." That change will appear in the UDB.
  * *adam*  (ASV: man, men) When referring to humanity in general, use "mankind."
  * *Call*  in the ASV usage "call his name": update to "**call him **  [+ name]" or "**name him **  [+ name]."
  * *Call*  in the formula of the type, "he shall be called the Son of the Most High" (Luke 1:32): keep this formula in the ULB, but be aware of the metaphor that is operative here: in this verse, Jesus will not only be *called the Son of the Most High*, but he will be the Son of the Most High.
  * *Hand*  indicating power or possession: we recommend that you keep this metaphor in the ULB.
  * *wehinneh *"**Behold**" (when used in normal narrative passages or in narrative embedded in direct speech). For conversational passages, see the preceding paragraph.
  * *YHWH* ,  * Jehovah, LORD  * (when referring to YHWH) "  ** Yahweh  ** " (The ASV uses "Jehovah," but we will not.)
  * *Meshiach* "***Messiah**" (almost always, "**the Messiah**," since "Messiah" is a title)
  * Sentence-initial or preverbal *and*  of the type, "and Joseph said," "and it came about," etc.: translate these without supplying "and." These occurrences of "and" in the ASV and its derivatives usually occur where the ASV translates the preverbal Greek particle *kai* or the Hebrew *vav * in the *wayyiqtol * verb form. The Greek particle *kai* was usually a Hebraism on the part of the New Testament writers that reflected their understanding that the Hebrew *wayyiqtol * form contained the conjunctive *vav* 'and.' This, however, was a misunderstanding, for modern scholarship has shown that the *wayyiqtol* form was a frozen form with parallels in cognate Semitic languages; it was the preferred Hebrew verb form for signaling event verbs in Hebrew narration. In some cases, good English style may require a preverbal "and." When it does, you are free to supply it. In most cases, however, English style does not require this "and." Note that the ASV very often supplies preverbal "and" even when there is no  * kai  * ​ in Greek, and even when Greek has the particle  * de  * , and, in fact, often when there is no Greek connective at all between clauses.
  * Expressions of the type, "he knew his wife" or "he went into his wife": try to use acceptable English euphemisms such as, "  ** he slept with his wife  ** ," "  ** he made love to his wife  ** ," or even "  ** they came together as man and wife  ** ." Every language has its own euphemisms for these ideas, and our English usage is simply to encourage them to employ their own. This general rule is as true for the UDB as for the ULB. To express a crime of this nature, try using, "  ** he forced himself on her  ** ."
  * ** Shall  ** vs.  ** will  ** : in English future expressions in general, use "  ** will  ** " instead of "shall," e.g., "he is a prophet, and he    <del>shall</del> ** will **  pray for you" (Gen 20:7). Note that some ASV future expressions are better updated into today's English by using the present tense, e.g., "I shall not drink from...the fruit of the vine, until the kingdom of God shall come" (Luke 22:18) can be updated to "I ** will **  not drink...until the kingdom of God ** comes**." Cases in which "shall" expresses obligation can usually be restructured, e.g., "You shall not steal" becomes " ** Do **  not steal," and "Shall I go and smite these Philistines?" (1 Sam. 23:2) becomes "**Should **  I go and attack these Philistines?" This general preference for "will" probably conforms to the instincts of most English native speakers. However, in genres such as prophecies, blessings, curses, and in other passages focusing on the expression of the speaker's intentionality, retain the use of "shall" in the ULB, e.g., "Yahweh said, **'Shall **  I hide from Abraham what I am about to do...?'" (Gen 18:17), " A deliverer **shall **  come to Zion," "every mountain and hill **shall **  be made low."
  * In speech introductions that use two verbs instead of one such as, "he answered and said," please retain this formula in the ULB. This will provide a model for languages which also separate the mode of speech from the act of speech, as does Biblical Hebrew. See the UDB for the same issue, however, where only one verb will be used.

#### Translation Glossary for the New Testament ULB

Preferred English renderings appear in bold type.

  * *nomikos* "**expert in the Jewish law**"
  * *brethren*  should be updated to **brothers**. When both genders are indicated by the context, a note from the Notes Team should be expected to appear to that effect. Do not replace the ULB text with "brothers and sisters." That change will appear in the UDB.
  * *Call* in the ASV usage "call his name": update to "call him [+ name]" or "name him [+ name]."
  * *Call* in the formula of the type, "he shall be called the Son of the Most High" (Luke 1:32): keep this formula in the ULB, but be aware of the metaphor that is operative here: in this verse, Jesus will not only be *called the Son of the Most High*, but he will be the Son of the Most High.
  * *grammateus*  "**scribe**"
  * *Hand*  indicating power or possession: we recommend that you keep this metaphor in the ULB.
  * *egeneto de*, *kai egeneto *  "**It came about**" (See: "Sentence-initial or preverbal *and***"*below)**.*
  * *idou*"  ** Behold  ** " (when used in normal narrative passages or in narrative embedded in direct speech. In conversational passages, translate  *idou preferably * as, "  ** look  ** ," "  ** see  ** ," "  ** see here  ** ," or at need as something else suitable for signaling that what immediately follows in the text is prominent. Some conversational contexts may make it almost impossible to give any translation at all of    *idou.*
  * *Messiah*  This term sometimes appears in the NT in transliterated Greek. You will have to evaluate each case, but in general this term should be translated, " ** Messiah ** ."
  * *Xristos* "**Christ**" or "**the Christ**" (if the term is being clearly used as a title; Paul often seems to use *Xristos *  as a second name for Jesus, but at times he clearly uses it as a title).
  * Sentence-initial or preverbal *and*  of the type, "and Joseph said," "and it came about," etc.: translate these without supplying "and." – These occurrences of "and" in the ASV and its derivatives usually occur where the ASV translates the preverbal Greek particle *kai* or the Hebrew *vav * in the *wayyiqtol * verb form. The Greek particle *kai* was usually a Hebraism on the part of the New Testament writers that reflected their understanding that the Hebrew *wayyiqtol * form contained the conjunctive *vav* 'and'. This, however, was a misunderstanding, for modern scholarship has shown that the *wayyiqtol* form was a frozen form with parallels in cognate Semitic languages; it was the preferred Hebrew verb form for signaling event verbs in Hebrew narration. – In some cases, good English style may require a preverbal "and." When it does, you are free to supply it. In most cases, however, English style does not require this "and." – Note that the ASV very often supplies preverbal "and" even when their is no  * kai  * ​ in Greek, and even when Greek has the particle  * de  * , and, in fact, often when there is no Greek connective at all between clauses.
  * Expressions of the type, "he knew his wife" or "he went into his wife": try to use acceptable English euphemisms such as, "he slept with his wife" or even "they came together as man and wife." Every language has its own euphemisms for these ideas, and our English usage is simply to encourage them to employ their own. This general rule is as true for the UDB as for the ULB.
  * ** Shall  ** vs.  ** will  ** : in English future expressions in general, use "  ** will  ** " instead of "shall," e.g., "he is a prophet, and he **will **  pray for you" (Gen 20:7). Note that some ASV future expressions are better updated into today's English by using the present tense, e.g., "I shall not drink from...the fruit of the vine, until the kingdom of God shall come" (Luke 22:18) can be updated to "I ** will **  not drink...until the kingdom of God ** comes**." Cases in which "shall" expresses obligation can usually be restructured, e.g., "You shall not steal" becomes "**Do **  not steal," and "Shall I go and smite these Philistines?" (1 Sam. 23:2) becomes "**Should **  I go and attack these Philistines?" This general preference for "will" probably conforms to the instincts of most English native speakers. However, in genres such as prophecies, blessings, curses, and in other passages focusing on the expression of the speaker's intentionality, retain the use of "shall," e.g., "Yahweh said, **'Shall **  I hide from Abraham what I am about to do...?'" (Gen 18:17), "A deliverer **shall **  come to Zion," "every mountain and hill **shall **  be made low."

### Notes regarding drafting ULB and UDB texts

1. The system we are using to draft these texts involves editors being able to edit the texts simultaneously. That means that what one editor deleted or added may be changed by another editor. However all the previous edits are preserved and can be viewed by using the timeline. The final editor will make decisions regarding what edits will be used for the final draft. Discussion about the edits or about alternate suggestions for the final editor to consider can be made in the chat boxes.

2. Although we are drafting these source texts in English, they will also be translated into other major languages (such as Spanish, French and others) to serve as source texts for people who know those languages and who will use these texts to translate into their own languages. Therefore the source texts have to be fairly easy to understand in order to be translated into the major languages, which in turn will need to be in a form that is easy to understand. Having them in natural English will set an example of naturalness that these other major languages can follow.

3. Translating from one language to another will involve changes in structure and differences in vocabulary. For example, one word in the first language may require two or more in the second language. The opposite will also be true, where the first language uses several words but the second language has to say it using only one word. Sometimes it is more natural in a language to omit a word like "is" (ex. Greek or Indonesian) whereas another language requires it (ex. English or French). The meaning is exactly the same but the way of expressing that meaning will be different depending on the language.

4. Strict adherence to certain words or structures at the expense of meaning results in a "translation" that does not preserve the meaning of the original text. So as these texts are drafted, we need to keep in mind that our aim is to faithfully communicate the meaning of the Greek and Hebrew text. A translation that does not make sense in the second language is not being faithful to the original text (which was written for the purpose of communicating a message). A stilted, unnatural translation obscures meaning, which is the opposite of what a translation should do.

5. Words will not always be translated exactly the same way every time they occur in the text since in every language, some words will have more than one meaning. One example in Greek is the word that can mean either "sky" or "heaven" depending on the context. In French the word for "dear" can also mean "expensive." The word "run" in English can have many different meanings. There are many more examples like these in other languages. In these cases, the meaning of the word is usually made clear by the other words and sentences surrounding it.

6. The goal of both the ULB and UDB texts is to accurately communicate the meaning of the Greek and Hebrew text. The ULB will also strive to keep as closely as possible to the Greek and Hebrew words and language structures as long as doing so does not change the meaning or make it hard to understand. The UDB will allow more flexibility so as to produce an even more natural English text that communicates the same meaning in a more dynamic way.

### Draft of a sample portion of ULB text

#### Types of edits to look for

* awkward phrasing
* outdated or low frequency vocabulary (and outdated spellings)
* wrong punctuation
* extraneous implied information
* unclear or unnatural use of pronouns or conjunctions
* wording that could cause a translation issue
* implied information that is important for comprehension
* original information lost

#### ULB Luke 12:1-3

Original, ASV text:

v. 1 In the meantime, when the many thousands of the multitude were gathered together, insomuch that they trod one upon another, he began to say to his disciples first of all, Beware you of the leaven of the Pharisees, which is hypocrisy.

v. 2 But there is nothing covered up, that shall not be revealed; and hid, that shall not be known.

v. 3 Wherefore whatever you have said in the darkness shall be heard in the light; and what you have spoken in the ear in the inner chambers shall be proclaimed upon the housetops.

Edited ULB text:

v. 1 Meanwhile, while many thousands of people were crowding together so much that they were stepping on each other, Jesus began to say to his disciples first of all, "Be on guard against the yeast of the Pharisees, which is hypocrisy."

v. 2 But there is nothing covered up that will not be revealed, and nothing hidden that will not be known.

v. 3 Therefore, whatever you say in the darkness will be heard in the light and whatever you have spoken in someone"s ear in a closet will be proclaimed from the roof of a house.

